@@ -244,12 +244,19 @@ class TextEdit(Model):
     new_text: str
 
 
+class ResourceOperationKind(str, enum.Enum):
+    Create = 'create'
+    Rename = 'rename'
+    Delete = 'delete'
+
+
 class CreateFileOptions(Model):
     overwrite: Optional[bool] = False
     ignore_if_exists: Optional[bool] = False
 
 
 class CreateFile(Model):
+    kind: ResourceOperationKind = ResourceOperationKind.Create
     uri: str
     options: Optional[CreateFileOptions] = None
 
@@ -260,6 +267,7 @@ class RenameFileOptions(Model):
 
 
 class RenameFile(Model):
+    kind: ResourceOperationKind = ResourceOperationKind.Rename
     old_uri: str
     new_uri: str
     options: Optional[RenameFileOptions] = None
@@ -271,16 +279,11 @@ class DeleteFileOptions(Model):
 
 
 class DeleteFile(Model):
+    kind: ResourceOperationKind = ResourceOperationKind.Delete
     uri: str
     options: Optional[DeleteFileOptions] = None
 
 
-class ResourceOperationKind(str, enum.Enum):
-    Create = 'create'
-    Rename = 'rename'
-    Delete = 'delete'
-
-
 class FailureHandlingKind(str, enum.Enum):
     Abort = 'abort'
     Transactional = 'transactional'
