@@ -48,6 +48,8 @@ async def aio_readline(loop, executor, stop_event, rfile, proxy):
     while not stop_event.is_set() and not rfile.closed:
         # Read a header line
         header = await loop.run_in_executor(executor, rfile.readline)
+        if not header:
+            break
         message.append(header)
 
         # Extract content length if possible
@@ -62,6 +64,8 @@ async def aio_readline(loop, executor, stop_event, rfile, proxy):
 
             # Read body
             body = await loop.run_in_executor(executor, rfile.read, content_length)
+            if not body:
+                break
             message.append(body)
 
             # Pass message to language server protocol
@@ -181,6 +185,8 @@ class Server:
                              self._stop_event,
                              stdin or sys.stdin.buffer,
                              self.lsp.data_received))
+        except BrokenPipeError:
+            logger.error('Connection to the client is lost! Shutting down the server.')
         except (KeyboardInterrupt, SystemExit):
             pass
         finally:
